@@ -30,7 +30,7 @@
 // POSSIBILITY OF SUCH DAMAGE.
 // ************************************************************************* 
 //
-// app/daction.js
+// app/daction-init.js
 //
 // Round one of daction initialization - called from app/target-init.js
 //
@@ -47,7 +47,8 @@ define ([
     return function () {
 
         //
-        // dactions, round one
+        // demo dactions that can safely be deleted after making sure they
+        // aren't mentioned anywhere in your app-specific code
         //
         target.push('demoActionFromMenu', {
             'name': 'demoActionFromMenu',
@@ -70,6 +71,16 @@ define ([
             'aclProfile': 'passerby',
             'start': dactionStart('demoActionFromSubmenu')
         }),
+        //
+        // dactions that you will probably want to use in your app
+        //
+        target.push('returnToBrowser', {
+            'name': 'returnToBrowser',
+            'type': 'daction',
+            'menuText': 'Return to browser',
+            'aclProfile': 'passerby',
+            'start': dactionStart('returnToBrowser')
+        }),
         target.push('logout', {
             'name': 'logout',
             'type': 'daction',
